@@ -66,9 +66,22 @@
 #ifdef HAVE_LIBGMP
 # include "a2gmp.h"
 #endif // HAVE_LIBGMP
+#include "LogFactory.h"
 
 #define A2_MIN_GCRYPT_VERSION "1.2.4"
 
+namespace {
+  void gnutls_log_callback(int level, const char *str)
+  {
+    using namespace aria2;
+    // GnuTLS adds a newline. Drop it.
+    std::string msg(str);
+    msg.resize(msg.size() - 1);
+    A2_LOG_DEBUG(fmt("GnuTLS: <%d> %s", level, msg.c_str()));
+  }
+}
+
+
 namespace aria2 {
 
 bool Platform::initialized_ = false;
@@ -103,6 +116,8 @@ bool Platform::setUp()
   // for SSL initialization
   SSL_load_error_strings();
   SSL_library_init();
+  // Need this to "decrypt" p12 files.
+  OpenSSL_add_all_algorithms();
 #endif // HAVE_OPENSSL
 #ifdef HAVE_LIBGCRYPT
   if(!gcry_check_version(A2_MIN_GCRYPT_VERSION)) {
@@ -118,6 +133,9 @@ bool Platform::setUp()
       throw DL_ABORT_EX(fmt("gnutls_global_init() failed, cause:%s",
                             gnutls_strerror(r)));
     }
+
+    gnutls_global_set_log_function(gnutls_log_callback);
+    gnutls_global_set_log_level(0);
   }
 #endif // HAVE_LIBGNUTLS
 
